summaryrefslogtreecommitdiffstats
path: root/kenolaba/Ball.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kenolaba/Ball.cpp')
-rw-r--r--kenolaba/Ball.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kenolaba/Ball.cpp b/kenolaba/Ball.cpp
index 392a61c5..39448305 100644
--- a/kenolaba/Ball.cpp
+++ b/kenolaba/Ball.cpp
@@ -21,14 +21,14 @@ void Ball::setSize(int x, int y)
sizeX = x;
sizeY = y;
- invalidate();
+ tqinvalidate();
}
-void Ball::invalidate()
+void Ball::tqinvalidate()
{
Ball *b;
/* invalidate all Balls... */
for(b=first;b!=0;b=b->next)
b->pm.resize(0,0);
}
@@ -43,7 +43,7 @@ void Ball::setLight(int x, int y, int z, const TQColor& c)
lightColor = c;
- invalidate();
+ tqinvalidate();
}
@@ -52,7 +52,7 @@ void Ball::setTexture(double c, double d)
rippleCount = c;
rippleDepth = d;
- invalidate();
+ tqinvalidate();
}
@@ -309,7 +309,7 @@ void BallWidget::resizeEvent(TQResizeEvent *)
realSize = (w>h) ? h:w;
Ball::setSize( realSize/ballFraction, realSize/ballFraction );
- repaint();
+ tqrepaint();
}
void BallWidget::paintEvent(TQPaintEvent *)
@@ -414,7 +414,7 @@ void BallWidget::animate()
timer->start(1000/freq,true);
}
- // repaint( false );
+ // tqrepaint( false );
}
@@ -21,14 +21,14 @@ void Ball::setSize(int x, int y)
{
Ball *b;
- /* invalidate all Balls... */
+ /* tqinvalidate all Balls... */
for(b=first;b!=0;b=b->next)
b->pm.resize(0,0);